l10n_countries library
Provides country translations for different locales.
Classes
- AaCountriesL10N
- Contains 3 translation(s). Provides translations for the Afar language locale.
- AbCountriesL10N
- Contains 250 translation(s). Provides translations for the Abkhaz language locale.
- AfCountriesL10N
- Contains 250 translation(s). Provides translations for the Afrikaans language locale.
- AkCountriesL10N
- Contains 168 translation(s). Provides translations for the Akan language locale.
- AmCountriesL10N
- Contains 250 translation(s). Provides translations for the Amharic language locale.
- AnCountriesL10N
- Contains 250 translation(s). Provides translations for the Aragonese language locale.
- ArCountriesL10N
- Contains 250 translation(s). Provides translations for the Arabic language locale.
- AsCountriesL10N
- Contains 250 translation(s). Provides translations for the Assamese language locale.
- AvCountriesL10N
- Contains 33 translation(s). Provides translations for the Avaric language locale.
- AyCountriesL10N
- Contains 52 translation(s). Provides translations for the Aymara language locale.
- AzCountriesL10N
- Contains 221 translation(s). Provides translations for the Azerbaijani language locale.
- AzCyrlCountriesL10N
- Contains 245 translation(s). Provides translations for the Azerbaijani language and Cyrillic script locale.
- BaCountriesL10N
- Contains 155 translation(s). Provides translations for the Bashkir language locale.
- BeCountriesL10N
- Contains 250 translation(s). Provides translations for the Belarusian language locale.
- BgCountriesL10N
- Contains 250 translation(s). Provides translations for the Bulgarian language locale.
- BhCountriesL10N
- Contains 36 translation(s). Provides translations for the Bihari language locale.
- BiCountriesL10N
- Contains 18 translation(s). Provides translations for the Bislama language locale.
- BmCountriesL10N
- Contains 223 translation(s). Provides translations for the Bambara language locale.
- BmLatnCountriesL10N
- Contains 3 translation(s). Provides translations for the Bambara language and Latin script locale.
- BnCountriesL10N
- Contains 250 translation(s). Provides translations for the Bengali (Bangla) language locale.
- BnInCountriesL10N
-
Contains 1 translation(s).
Provides translations for the Bengali (Bangla) language
and
INcountry/region code locale. - BoCountriesL10N
- Contains 203 translation(s). Provides translations for the Tibetan Standard language locale.
- BrCountriesL10N
- Contains 250 translation(s). Provides translations for the Breton language locale.
- BsCountriesL10N
- Contains 204 translation(s). Provides translations for the Bosnian language locale.
- BsCyrlCountriesL10N
- Contains 249 translation(s). Provides translations for the Bosnian language and Cyrillic script locale.
- CaCountriesL10N
- Contains 250 translation(s). Provides translations for the Catalan language locale.
- CeCountriesL10N
- Contains 250 translation(s). Provides translations for the Chechen language locale.
- ChCountriesL10N
- Contains 8 translation(s). Provides translations for the Chamorro language locale.
- CoCountriesL10N
- Contains 66 translation(s). Provides translations for the Corsican language locale.
- CountriesLocaleMapper
- Provides country names translations for different locales.
- CsCountriesL10N
- Contains 250 translation(s). Provides translations for the Czech language locale.
- CuCountriesL10N
- Contains 69 translation(s). Provides translations for the (Old) Church Slavonic language locale.
- CvCountriesL10N
- Contains 250 translation(s). Provides translations for the Chuvash language locale.
- CyCountriesL10N
- Contains 250 translation(s). Provides translations for the Welsh language locale.
- DaCountriesL10N
- Contains 250 translation(s). Provides translations for the Danish language locale.
- DeCountriesL10N
- Contains 250 translation(s). Provides translations for the German language locale.
- DvCountriesL10N
- Contains 178 translation(s). Provides translations for the Divehi (Dhivehi/Maldivian) language locale.
- DzCountriesL10N
- Contains 250 translation(s). Provides translations for the Dzongkha language locale.
- EeCountriesL10N
- Contains 250 translation(s). Provides translations for the Ewe language locale.
- ElCountriesL10N
- Contains 250 translation(s). Provides translations for the Greek (modern) language locale.
- EnCountriesL10N
- Contains 250 translation(s). Provides translations for the English language locale.
- EoCountriesL10N
- Contains 250 translation(s). Provides translations for the Esperanto language locale.
- EsCountriesL10N
- Contains 250 translation(s). Provides translations for the Spanish language locale.
- EtCountriesL10N
- Contains 250 translation(s). Provides translations for the Estonian language locale.
- EuCountriesL10N
- Contains 250 translation(s). Provides translations for the Basque language locale.
- FaCountriesL10N
- Contains 250 translation(s). Provides translations for the Persian (Farsi) language locale.
- FfCountriesL10N
- Contains 250 translation(s). Provides translations for the Fula (Fulah/Pulaar/Pular) language locale.
- FiCountriesL10N
- Contains 250 translation(s). Provides translations for the Finnish language locale.
- FjCountriesL10N
- Contains 6 translation(s). Provides translations for the Fijian language locale.
- FoCountriesL10N
- Contains 250 translation(s). Provides translations for the Faroese language locale.
- FrCountriesL10N
- Contains 250 translation(s). Provides translations for the French language locale.
- FyCountriesL10N
- Contains 250 translation(s). Provides translations for the Western Frisian language locale.
- GaCountriesL10N
- Contains 250 translation(s). Provides translations for the Irish language locale.
- GdCountriesL10N
- Contains 250 translation(s). Provides translations for the (Scottish) Gaelic language locale.
- GlCountriesL10N
- Contains 250 translation(s). Provides translations for the Galician language locale.
- GnCountriesL10N
- Contains 101 translation(s). Provides translations for the Guaraní language locale.
- GuCountriesL10N
- Contains 250 translation(s). Provides translations for the Gujarati language locale.
- GvCountriesL10N
- Contains 155 translation(s). Provides translations for the Manx language locale.
- HaCountriesL10N
- Contains 250 translation(s). Provides translations for the Hausa language locale.
- HaLatnCountriesL10N
- Contains 17 translation(s). Provides translations for the Hausa language and Latin script locale.
- HeCountriesL10N
- Contains 250 translation(s). Provides translations for the Hebrew (modern) language locale.
- HiCountriesL10N
- Contains 250 translation(s). Provides translations for the Hindi language locale.
- HrCountriesL10N
- Contains 250 translation(s). Provides translations for the Croatian language locale.
- HtCountriesL10N
- Contains 152 translation(s). Provides translations for the Haitian (Haitian Creole) language locale.
- HuCountriesL10N
- Contains 250 translation(s). Provides translations for the Hungarian language locale.
- HyCountriesL10N
- Contains 250 translation(s). Provides translations for the Armenian language locale.
- IaCountriesL10N
- Contains 250 translation(s). Provides translations for the Interlingua language locale.
- IdCountriesL10N
- Contains 250 translation(s). Provides translations for the Indonesian language locale.
- IeCountriesL10N
- Contains 250 translation(s). Provides translations for the Interlingue language locale.
- IgCountriesL10N
- Contains 250 translation(s). Provides translations for the Igbo language locale.
- IiCountriesL10N
- Contains 10 translation(s). Provides translations for the Nuosu language locale.
- IkCountriesL10N
- Contains 7 translation(s). Provides translations for the Inupiaq language locale.
- IoCountriesL10N
- Contains 114 translation(s). Provides translations for the Ido language locale.
- IsCountriesL10N
- Contains 250 translation(s). Provides translations for the Icelandic language locale.
-
IsoLocaleMapper<
V extends Object> - A class that handles mapping between ISO codes and their localized values.
- ItCountriesL10N
- Contains 250 translation(s). Provides translations for the Italian language locale.
- IuCountriesL10N
- Contains 25 translation(s). Provides translations for the Inuktitut language locale.
- JaCountriesL10N
- Contains 250 translation(s). Provides translations for the Japanese language locale.
- JvCountriesL10N
- Contains 250 translation(s). Provides translations for the Javanese language locale.
- KaCountriesL10N
- Contains 250 translation(s). Provides translations for the Georgian language locale.
- KgCountriesL10N
- Contains 68 translation(s). Provides translations for the Kongo language locale.
- KiCountriesL10N
- Contains 224 translation(s). Provides translations for the Kikuyu (Gikuyu) language locale.
- KkCountriesL10N
- Contains 249 translation(s). Provides translations for the Kazakh language locale.
- KkCyrlCountriesL10N
- Contains 35 translation(s). Provides translations for the Kazakh language and Cyrillic script locale.
- KlCountriesL10N
- Contains 220 translation(s). Provides translations for the Kalaallisut (Greenlandic) language locale.
- KmCountriesL10N
- Contains 250 translation(s). Provides translations for the Khmer language locale.
- KnCountriesL10N
- Contains 250 translation(s). Provides translations for the Kannada language locale.
- KoCountriesL10N
- Contains 250 translation(s). Provides translations for the Korean language locale.
- KsArabCountriesL10N
- Contains 65 translation(s). Provides translations for the Kashmiri language and Arabic script locale.
- KsCountriesL10N
- Contains 250 translation(s). Provides translations for the Kashmiri language locale.
- KuCountriesL10N
- Contains 214 translation(s). Provides translations for the Kurdish language locale.
- KvCountriesL10N
- Contains 103 translation(s). Provides translations for the Komi language locale.
- KwCountriesL10N
- Contains 146 translation(s). Provides translations for the Cornish language locale.
- KyCountriesL10N
- Contains 249 translation(s). Provides translations for the Kyrgyz language locale.
- KyCyrlCountriesL10N
- Contains 32 translation(s). Provides translations for the Kyrgyz language and Cyrillic script locale.
- LaCountriesL10N
- Contains 240 translation(s). Provides translations for the Latin language locale.
- LbCountriesL10N
- Contains 250 translation(s). Provides translations for the Luxembourgish (Letzeburgesch) language locale.
- LgCountriesL10N
- Contains 224 translation(s). Provides translations for the Ganda language locale.
- LiCountriesL10N
- Contains 119 translation(s). Provides translations for the Limburgish (Limburgan/Limburger) language locale.
- LnCountriesL10N
- Contains 246 translation(s). Provides translations for the Lingala language locale.
- LoCountriesL10N
- Contains 250 translation(s). Provides translations for the Lao language locale.
- LtCountriesL10N
- Contains 250 translation(s). Provides translations for the Lithuanian language locale.
- LuCountriesL10N
- Contains 200 translation(s). Provides translations for the Luba-Katanga language locale.
- LvCountriesL10N
- Contains 250 translation(s). Provides translations for the Latvian language locale.
- MgCountriesL10N
- Contains 224 translation(s). Provides translations for the Malagasy language locale.
- MiCountriesL10N
- Contains 250 translation(s). Provides translations for the Māori language locale.
- MkCountriesL10N
- Contains 250 translation(s). Provides translations for the Macedonian language locale.
- MlCountriesL10N
- Contains 250 translation(s). Provides translations for the Malayalam language locale.
- MnCountriesL10N
- Contains 249 translation(s). Provides translations for the Mongolian language locale.
- MnCyrlCountriesL10N
- Contains 66 translation(s). Provides translations for the Mongolian language and Cyrillic script locale.
- MrCountriesL10N
- Contains 250 translation(s). Provides translations for the Marathi (Marāṭhī) language locale.
- MsCountriesL10N
- Contains 249 translation(s). Provides translations for the Malay language locale.
- MsLatnCountriesL10N
- Contains 5 translation(s). Provides translations for the Malay language and Latin script locale.
- MtCountriesL10N
- Contains 250 translation(s). Provides translations for the Maltese language locale.
- MyCountriesL10N
- Contains 250 translation(s). Provides translations for the Burmese language locale.
- NaCountriesL10N
- Contains 112 translation(s). Provides translations for the Nauruan language locale.
- NbCountriesL10N
- Contains 250 translation(s). Provides translations for the Norwegian Bokmål language locale.
- NdCountriesL10N
- Contains 105 translation(s). Provides translations for the Northern Ndebele language locale.
- NeCountriesL10N
- Contains 250 translation(s). Provides translations for the Nepali language locale.
- NlCountriesL10N
- Contains 250 translation(s). Provides translations for the Dutch language locale.
- NnCountriesL10N
- Contains 116 translation(s). Provides translations for the Norwegian Nynorsk language locale.
- NoCountriesL10N
- Contains 250 translation(s). Provides translations for the Norwegian language locale.
- NvCountriesL10N
- Contains 129 translation(s). Provides translations for the Navajo (Navaho) language locale.
- NyCountriesL10N
- Contains 2 translation(s). Provides translations for the Chichewa (Chewa/Nyanja) language locale.
- OcCountriesL10N
- Contains 250 translation(s). Provides translations for the Occitan language locale.
- OmCountriesL10N
- Contains 50 translation(s). Provides translations for the Oromo language locale.
- OrCountriesL10N
- Contains 250 translation(s). Provides translations for the Oriya language locale.
- OsCountriesL10N
- Contains 180 translation(s). Provides translations for the Ossetian (Ossetic) language locale.
- PaArabCountriesL10N
- Contains 1 translation(s). Provides translations for the (Eastern) Punjabi language and Arabic script locale.
- PaCountriesL10N
- Contains 250 translation(s). Provides translations for the (Eastern) Punjabi language locale.
- PiCountriesL10N
- Contains 32 translation(s). Provides translations for the Pāli language locale.
- PlCountriesL10N
- Contains 250 translation(s). Provides translations for the Polish language locale.
- PsCountriesL10N
- Contains 250 translation(s). Provides translations for the Pashto (Pushto) language locale.
- PsPkCountriesL10N
-
Contains 3 translation(s).
Provides translations for the Pashto (Pushto) language
and
PKcountry/region code locale. - PtCountriesL10N
- Contains 250 translation(s). Provides translations for the Portuguese language locale.
- QuCountriesL10N
- Contains 250 translation(s). Provides translations for the Quechua language locale.
- RmCountriesL10N
- Contains 250 translation(s). Provides translations for the Romansh language locale.
- RnCountriesL10N
- Contains 224 translation(s). Provides translations for the Kirundi language locale.
- RoCountriesL10N
- Contains 250 translation(s). Provides translations for the Romanian language locale.
- RoMdCountriesL10N
-
Contains 1 translation(s).
Provides translations for the Romanian language
and
MDcountry/region code locale. - RuCountriesL10N
- Contains 250 translation(s). Provides translations for the Russian language locale.
- RwCountriesL10N
- Contains 165 translation(s). Provides translations for the Kinyarwanda language locale.
- SaCountriesL10N
- Contains 153 translation(s). Provides translations for the Sanskrit (Saṁskṛta) language locale.
- ScCountriesL10N
- Contains 250 translation(s). Provides translations for the Sardinian language locale.
- SdCountriesL10N
- Contains 250 translation(s). Provides translations for the Sindhi language locale.
- SeCountriesL10N
- Contains 247 translation(s). Provides translations for the Northern Sami language locale.
- SeFiCountriesL10N
-
Contains 2 translation(s).
Provides translations for the Northern Sami language
and
FIcountry/region code locale. - SgCountriesL10N
- Contains 225 translation(s). Provides translations for the Sango language locale.
- SiCountriesL10N
- Contains 250 translation(s). Provides translations for the Sinhalese (Sinhala) language locale.
- SkCountriesL10N
- Contains 250 translation(s). Provides translations for the Slovak language locale.
- SlCountriesL10N
- Contains 250 translation(s). Provides translations for the Slovene language locale.
- SmCountriesL10N
- Contains 45 translation(s). Provides translations for the Samoan language locale.
- SnCountriesL10N
- Contains 224 translation(s). Provides translations for the Shona language locale.
- SoCountriesL10N
- Contains 250 translation(s). Provides translations for the Somali language locale.
- SqCountriesL10N
- Contains 249 translation(s). Provides translations for the Albanian language locale.
- SrCountriesL10N
- Contains 250 translation(s). Provides translations for the Serbian language locale.
- SsCountriesL10N
- Contains 150 translation(s). Provides translations for the Swati language locale.
- StCountriesL10N
- Contains 7 translation(s). Provides translations for the Southern Sotho language locale.
- SuCountriesL10N
- Contains 111 translation(s). Provides translations for the Sundanese language locale.
- SvCountriesL10N
- Contains 250 translation(s). Provides translations for the Swedish language locale.
- SwCdCountriesL10N
-
Contains 28 translation(s).
Provides translations for the Swahili language
and
CDcountry/region code locale. - SwCountriesL10N
- Contains 250 translation(s). Provides translations for the Swahili language locale.
- SwKeCountriesL10N
-
Contains 42 translation(s).
Provides translations for the Swahili language
and
KEcountry/region code locale. - TaCountriesL10N
- Contains 250 translation(s). Provides translations for the Tamil language locale.
- TeCountriesL10N
- Contains 250 translation(s). Provides translations for the Telugu language locale.
- TgCountriesL10N
- Contains 245 translation(s). Provides translations for the Tajik language locale.
- ThCountriesL10N
- Contains 250 translation(s). Provides translations for the Thai language locale.
- TiCountriesL10N
- Contains 250 translation(s). Provides translations for the Tigrinya language locale.
- TkCountriesL10N
- Contains 250 translation(s). Provides translations for the Turkmen language locale.
- TlCountriesL10N
- Contains 250 translation(s). Provides translations for the Tagalog language locale.
- TnCountriesL10N
- Contains 2 translation(s). Provides translations for the Tswana language locale.
- ToCountriesL10N
- Contains 250 translation(s). Provides translations for the Tonga (Tonga Islands) language locale.
- TrCountriesL10N
- Contains 250 translation(s). Provides translations for the Turkish language locale.
- TsCountriesL10N
- Contains 25 translation(s). Provides translations for the Tsonga language locale.
- TtCountriesL10N
- Contains 246 translation(s). Provides translations for the Tatar language locale.
- TwCountriesL10N
- Contains 9 translation(s). Provides translations for the Twi language locale.
- TyCountriesL10N
- Contains 24 translation(s). Provides translations for the Tahitian language locale.
- UgArabCountriesL10N
- Contains 60 translation(s). Provides translations for the Uyghur language and Arabic script locale.
- UgCountriesL10N
- Contains 249 translation(s). Provides translations for the Uyghur language locale.
- UkCountriesL10N
- Contains 250 translation(s). Provides translations for the Ukrainian language locale.
- UrCountriesL10N
- Contains 250 translation(s). Provides translations for the Urdu language locale.
- UzCountriesL10N
- Contains 211 translation(s). Provides translations for the Uzbek language locale.
- UzCyrlCountriesL10N
- Contains 249 translation(s). Provides translations for the Uzbek language and Cyrillic script locale.
- VeCountriesL10N
- Contains 10 translation(s). Provides translations for the Venda language locale.
- ViCountriesL10N
- Contains 250 translation(s). Provides translations for the Vietnamese language locale.
- VoCountriesL10N
- Contains 194 translation(s). Provides translations for the Volapük language locale.
- WaCountriesL10N
- Contains 58 translation(s). Provides translations for the Walloon language locale.
- WoCountriesL10N
- Contains 247 translation(s). Provides translations for the Wolof language locale.
- XhCountriesL10N
- Contains 250 translation(s). Provides translations for the Xhosa language locale.
- YiCountriesL10N
- Contains 216 translation(s). Provides translations for the Yiddish language locale.
- YoBjCountriesL10N
-
Contains 224 translation(s).
Provides translations for the Yoruba language
and
BJcountry/region code locale. - YoCountriesL10N
- Contains 250 translation(s). Provides translations for the Yoruba language locale.
- ZaCountriesL10N
- Contains 188 translation(s). Provides translations for the Zhuang (Chuang) language locale.
- ZhCountriesL10N
- Contains 250 translation(s). Provides translations for the Chinese language locale.
- ZuCountriesL10N
- Contains 250 translation(s). Provides translations for the Zulu language locale.