HaCountriesL10N class

Contains 250 translation(s). Provides translations for the Hausa language locale.

Inheritance

Constructors

HaCountriesL10N()
Provides country translations for the ha locale.

Properties

availableLocales Set<String>
Returns all available locale keys (both lazy and already instantiated).
finalinherited
hashCode int
The hash code for this object.
no setterinherited
map Map<String, String>
The internal mapping between ISO codes and their values.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

altKey(String key, String altSymbol) String?
Generates an alternative key by appending a symbol to the original key.
inherited
extract(Iterable<String>? keys, {String altSymbol = ""}) Map<String, String>
Extracts values for specified keys from the internal map.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited